
import { localize } from '@codingame/monaco-vscode-api/vscode/vs/nls';
import { Schemas } from './problemMatcher.js';

const schema = {
    definitions: {
        showOutputType: {
            type: 'string',
            enum: ['always', 'silent', 'never']
        },
        options: {
            type: 'object',
            description: ( localize(9346, 'Additional command options')),
            properties: {
                cwd: {
                    type: 'string',
                    description: ( localize(
                        9347,
                        'The current working directory of the executed program or script. If omitted Code\'s current workspace root is used.'
                    ))
                },
                env: {
                    type: 'object',
                    additionalProperties: {
                        type: 'string'
                    },
                    description: ( localize(
                        9348,
                        'The environment of the executed program or shell. If omitted the parent process\' environment is used.'
                    ))
                }
            },
            additionalProperties: {
                type: ['string', 'array', 'object']
            }
        },
        problemMatcherType: {
            oneOf: [
                {
                    type: 'string',
                    errorMessage: ( localize(
                        9349,
                        'Unrecognized problem matcher. Is the extension that contributes this problem matcher installed?'
                    ))
                },
                Schemas.LegacyProblemMatcher,
                {
                    type: 'array',
                    items: {
                        anyOf: [
                            {
                                type: 'string',
                                errorMessage: ( localize(
                                    9349,
                                    'Unrecognized problem matcher. Is the extension that contributes this problem matcher installed?'
                                ))
                            },
                            Schemas.LegacyProblemMatcher
                        ]
                    }
                }
            ]
        },
        shellConfiguration: {
            type: 'object',
            additionalProperties: false,
            description: ( localize(9350, 'Configures the shell to be used.')),
            properties: {
                executable: {
                    type: 'string',
                    description: ( localize(9351, 'The shell to be used.'))
                },
                args: {
                    type: 'array',
                    description: ( localize(9352, 'The shell arguments.')),
                    items: {
                        type: 'string'
                    }
                }
            }
        },
        commandConfiguration: {
            type: 'object',
            additionalProperties: false,
            properties: {
                command: {
                    type: 'string',
                    description: ( localize(
                        9353,
                        'The command to be executed. Can be an external program or a shell command.'
                    ))
                },
                args: {
                    type: 'array',
                    description: ( localize(9354, 'Arguments passed to the command when this task is invoked.')),
                    items: {
                        type: 'string'
                    }
                },
                options: {
                    $ref: '#/definitions/options'
                }
            }
        },
        taskDescription: {
            type: 'object',
            required: ['taskName'],
            additionalProperties: false,
            properties: {
                taskName: {
                    type: 'string',
                    description: ( localize(9355, "The task's name"))
                },
                command: {
                    type: 'string',
                    description: ( localize(
                        9353,
                        'The command to be executed. Can be an external program or a shell command.'
                    ))
                },
                args: {
                    type: 'array',
                    description: ( localize(9354, 'Arguments passed to the command when this task is invoked.')),
                    items: {
                        type: 'string'
                    }
                },
                options: {
                    $ref: '#/definitions/options'
                },
                windows: {
                    anyOf: [
                        {
                            $ref: '#/definitions/commandConfiguration',
                            description: ( localize(9356, 'Windows specific command configuration')),
                        },
                        {
                            properties: {
                                problemMatcher: {
                                    $ref: '#/definitions/problemMatcherType',
                                    description: ( localize(
                                        9357,
                                        'The problem matcher(s) to use. Can either be a string or a problem matcher definition or an array of strings and problem matchers.'
                                    ))
                                }
                            }
                        }
                    ]
                },
                osx: {
                    anyOf: [
                        {
                            $ref: '#/definitions/commandConfiguration',
                            description: ( localize(9358, 'Mac specific command configuration'))
                        },
                        {
                            properties: {
                                problemMatcher: {
                                    $ref: '#/definitions/problemMatcherType',
                                    description: ( localize(
                                        9357,
                                        'The problem matcher(s) to use. Can either be a string or a problem matcher definition or an array of strings and problem matchers.'
                                    ))
                                }
                            }
                        }
                    ]
                },
                linux: {
                    anyOf: [
                        {
                            $ref: '#/definitions/commandConfiguration',
                            description: ( localize(9359, 'Linux specific command configuration'))
                        },
                        {
                            properties: {
                                problemMatcher: {
                                    $ref: '#/definitions/problemMatcherType',
                                    description: ( localize(
                                        9357,
                                        'The problem matcher(s) to use. Can either be a string or a problem matcher definition or an array of strings and problem matchers.'
                                    ))
                                }
                            }
                        }
                    ]
                },
                suppressTaskName: {
                    type: 'boolean',
                    description: ( localize(
                        9360,
                        'Controls whether the task name is added as an argument to the command. If omitted the globally defined value is used.'
                    )),
                    default: true
                },
                showOutput: {
                    $ref: '#/definitions/showOutputType',
                    description: ( localize(
                        9361,
                        'Controls whether the output of the running task is shown or not. If omitted the globally defined value is used.'
                    ))
                },
                echoCommand: {
                    type: 'boolean',
                    description: ( localize(
                        9362,
                        'Controls whether the executed command is echoed to the output. Default is false.'
                    )),
                    default: true
                },
                isWatching: {
                    type: 'boolean',
                    deprecationMessage: ( localize(9363, 'Deprecated. Use isBackground instead.')),
                    description: ( localize(
                        9364,
                        'Whether the executed task is kept alive and is watching the file system.'
                    )),
                    default: true
                },
                isBackground: {
                    type: 'boolean',
                    description: ( localize(
                        9365,
                        'Whether the executed task is kept alive and is running in the background.'
                    )),
                    default: true
                },
                promptOnClose: {
                    type: 'boolean',
                    description: ( localize(
                        9366,
                        'Whether the user is prompted when VS Code closes with a running task.'
                    )),
                    default: false
                },
                isBuildCommand: {
                    type: 'boolean',
                    description: ( localize(9367, 'Maps this task to Code\'s default build command.')),
                    default: true
                },
                isTestCommand: {
                    type: 'boolean',
                    description: ( localize(9368, 'Maps this task to Code\'s default test command.')),
                    default: true
                },
                problemMatcher: {
                    $ref: '#/definitions/problemMatcherType',
                    description: ( localize(
                        9357,
                        'The problem matcher(s) to use. Can either be a string or a problem matcher definition or an array of strings and problem matchers.'
                    ))
                }
            }
        },
        taskRunnerConfiguration: {
            type: 'object',
            required: [],
            properties: {
                command: {
                    type: 'string',
                    description: ( localize(
                        9353,
                        'The command to be executed. Can be an external program or a shell command.'
                    ))
                },
                args: {
                    type: 'array',
                    description: ( localize(9369, 'Additional arguments passed to the command.')),
                    items: {
                        type: 'string'
                    }
                },
                options: {
                    $ref: '#/definitions/options'
                },
                showOutput: {
                    $ref: '#/definitions/showOutputType',
                    description: ( localize(
                        9370,
                        'Controls whether the output of the running task is shown or not. If omitted \'always\' is used.'
                    ))
                },
                isWatching: {
                    type: 'boolean',
                    deprecationMessage: ( localize(9371, 'Deprecated. Use isBackground instead.')),
                    description: ( localize(
                        9372,
                        'Whether the executed task is kept alive and is watching the file system.'
                    )),
                    default: true
                },
                isBackground: {
                    type: 'boolean',
                    description: ( localize(
                        9373,
                        'Whether the executed task is kept alive and is running in the background.'
                    )),
                    default: true
                },
                promptOnClose: {
                    type: 'boolean',
                    description: ( localize(
                        9374,
                        'Whether the user is prompted when VS Code closes with a running background task.'
                    )),
                    default: false
                },
                echoCommand: {
                    type: 'boolean',
                    description: ( localize(
                        9362,
                        'Controls whether the executed command is echoed to the output. Default is false.'
                    )),
                    default: true
                },
                suppressTaskName: {
                    type: 'boolean',
                    description: ( localize(
                        9375,
                        'Controls whether the task name is added as an argument to the command. Default is false.'
                    )),
                    default: true
                },
                taskSelector: {
                    type: 'string',
                    description: ( localize(9376, 'Prefix to indicate that an argument is task.'))
                },
                problemMatcher: {
                    $ref: '#/definitions/problemMatcherType',
                    description: ( localize(
                        9377,
                        'The problem matcher(s) to use. Can either be a string or a problem matcher definition or an array of strings and problem matchers.'
                    ))
                },
                tasks: {
                    type: 'array',
                    description: ( localize(
                        9378,
                        'The task configurations. Usually these are enrichments of task already defined in the external task runner.'
                    )),
                    items: {
                        type: 'object',
                        $ref: '#/definitions/taskDescription'
                    }
                }
            }
        }
    }
};

export { schema as default };
